<template>
    <div class="content">
        <div class="el-card_top">
            <el-form :inline="true" :model="formInline">
                <el-form-item label="公司" prop="companyName">
                    <CascaderCompany
                        :value="formInline.companyIds"
                        @changecom="companyChange"
                        :placeholder="'请选择公司名称'"
                    />
                </el-form-item>
                <el-form-item label="年份">
                    <el-date-picker
                        v-model="formInline.year"
                        type="year"
                        placeholder="请选择年限"
                        value-format="yyyy"
                        @change="changeYear"
                    >
                    </el-date-picker>
                </el-form-item>
            </el-form>
        </div>
        <div class="content-main">
            <div class="title">
                <h1>日常养护</h1>
            </div>
            <div class="main">
                <div class="item-left">
                    <div class="top">
                        <p>
                            <i class="el-icon-pie-chart"></i>
                        </p>
                        <h1>各类别工单数量统计</h1>
                    </div>
                    <div
                        class="box"
                        v-loading="loading1"
                        element-loading-text="加载中"
                        element-loading-spinner="el-icon-loading"
                        element-loading-background="rgba(0, 0, 0, 0.3)"
                    >
                        <div class="box-item" v-for="item in data" :key="item.pcode">
                            <span>{{ item.pname }}</span>
                            <div class="box-progress">
                                <el-progress
                                    :percentage="item.percentage"
                                    color="#11d9f2"
                                    :show-text="false"
                                ></el-progress>
                            </div>
                            <span>{{ item.pnameCount }}</span>
                        </div>
                    </div>
                </div>
                <div class="item-right">
                    <div class="top">
                        <p>
                            <i class="el-icon-pie-chart"></i>
                        </p>
                        <h1>日常养护金额统计</h1>
                    </div>
                    <div
                        class="box"
                        v-loading="loading2"
                        element-loading-text="加载中"
                        element-loading-spinner="el-icon-loading"
                        element-loading-background="rgba(0, 0, 0, 0.3)"
                    >
                        <div
                            id="amountStatisticsChart"
                            :style="{width: '100%', height: '100%'}"
                        ></div>
                    </div>
                </div>
            </div>
            <div class="main">
                <div class="item-left">
                    <div class="top">
                        <p>
                            <i class="el-icon-pie-chart"></i>
                        </p>
                        <h1>养护工单执行状态统计</h1>
                    </div>
                    <div
                        class="box height_400"
                        v-loading="loading3"
                        element-loading-text="加载中"
                        element-loading-spinner="el-icon-loading"
                        element-loading-background="rgba(0, 0, 0, 0.3)"
                    >
                        <div
                            id="statusChart"
                            :style="{width: '100%', height: '100%'}"
                        ></div>
                    </div>
                </div>
                <div class="item-right">
                    <div class="top">
                        <p>
                            <i class="el-icon-pie-chart"></i>
                        </p>
                        <h1>养护工单所属路段统计</h1>
                    </div>
                    <div
                        class="box height_400"
                        v-loading="loading4"
                        element-loading-text="加载中"
                        element-loading-spinner="el-icon-loading"
                        element-loading-background="rgba(0, 0, 0, 0.3)"
                    >
                        <div
                            id="roadChart"
                            :style="{width: '100%', height: '100%'}"
                        ></div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</template>

<script>
import * as echarts from 'echarts'
import CascaderCompany from './components/CascaderCompany_.vue'
export default {
    name: 'DailyMaintenanceStatistics',
    components: {
        CascaderCompany,
    },
    data() {
        return {
            data: [],
            loading1: false,
            loading2: false,
            loading3: false,
            loading4: false,
            formInline: {
                companyIds: ['1419863231459102720', '1430734631036129280'],
                companyName: '',
                roadSegmentName: '',
                year: new Date(),
            },
            params: {
                pageBean: {
                    page: -1,
                    pageSize: 10,
                    showTotal: true,
                },
                params: {roadSegmentId: '', accDateYear: new Date().getFullYear()},
            },
            cstatus: '', // 传递到工单信息是否已完成的选项搜索栏的值
        }
    },
    created() {},
    mounted() {
        this.companyChange(['1419863231459102720', '1430734631036129280'])
    },
    methods: {
        changeYear(val) {
            this.params.params.accDateYear = val
            this.companyChange(this.formInline.companyIds)
        },
        companyChange(val) {
            this.formInline.companyIds = val
            let id = (val && val[val.length - 1]) || ''
            if (!id) return
            this.loading1 = true
            this.loading2 = true
            this.loading3 = true
            this.loading4 = true
            this.$http
                .get('${yhxt}/statisticalStatement/v1/findAllRoadIds?id=' + id)
                .then((res) => {
                    let ids = res.data.value.join(',') || id || ''
                    if (!ids) {
                        this.loading1 = false
                        this.loading2 = false
                        this.loading3 = false
                        this.loading4 = false
                        this.data = []
                        this.getRoadChart([])
                        this.getAmountStatisticsChart([])
                    } else {
                        this.getCountMaintenanceData(ids)
                        this.getTotalMoney(ids)
                    }
                })
        },
        getCountMaintenanceData(roadSegmentId) {
            let {accDateYear} = this.params.params
            this.$http
                .post('${yhxt}/statisticalStatement/v1/countMaintenance/new', {
                    roadSegmentId,
                    accDateYear: accDateYear,
                })
                .then((res) => {
                    this.loading1 = false
                    this.loading2 = false
                    this.data = res.data.maintenanceNewVos
                    this.format(this.data)
                    this.getAmountStatisticsChart(res.data.maintenanceNewVos)
                })
        },
        getTotalMoney(id) {
            this.params.params.roadSegmentId = id
            this.$http
                .post('${yhxt}/bizWorkStatistic/v1/newCountWorkOrder', this.params)
                .then((res) => {
                    this.loading3 = false
                    this.loading4 = false
                    this.getRoadChart(res.data)
                    this.getStatusCharts(res.data)
                })
        },
        format(data) {
            let total = 0
            let money = 0
            data.forEach((item) => {
                total += Number(item.pnameCount)
                money += Number(item.everyMoney)
            })
            console.log(total)
            data.forEach((item) => {
                item.percentage = (item.pnameCount / total) * 100
                item.percent = Number(((item.everyMoney / money) * 100).toFixed(2))
                item.money = (Number(item.everyMoney) / 10000).toFixed(2)
            })
            console.log(data)
        },
        getAmountStatisticsChart(data) {
            let chartDom = document.getElementById('amountStatisticsChart')
            let myChart = echarts.init(chartDom)
            let data_ = []

            data.forEach((item) => {
                data_.push({
                    value: item.percent,
                    name: item.pname,
                    money: item.money,
                })
            })
            let option = {
                title: {
                    textStyle: {
                        color: '#fff',
                    },
                },
                legend: {
                    orient: 'vertical',
                    right: 30,
                    top: 'center',
                    bottom: 20,
                    show: false,
                    textStyle: {
                        color: '#fff',
                    },
                },
                tooltip: {
                    trigger: 'item',
                    formatter: (a) => {
                        return `${a.marker} ${a.data.name} 总额:${a.data.money}万元 占比:${a.data.value}%`
                    },
                },
                color: ['#16ffae', '#00e6f6', '#6255f8', '#0282b9'],
                series: [
                    {
                        type: 'pie',
                        radius: ['40%', '60%'],
                        data: data_,
                        // width: '75%',
                        center: ['50%', '50%'],
                        minAngle: 10, // 设置每块扇形的最小占比
                        label: {
                            alignTo: 'edge',
                            // show: false,
                            // formatter: '{name|{b}}{money|{}}\n\n{percent|{c} %}',
                            formatter: (a) => {
                                return `{name|${a.data.name}} {money|${a.data.money} 万元} {percent|${a.data.value} %}`
                            },
                            minMargin: 5,
                            edgeDistance: 10,
                            //   lineHeight: 18,
                            rich: {
                                name: {
                                    fontSize: 18,
                                    color: '#fff',
                                },
                                money: {
                                    fontSize: 14,
                                    color: '#fff',
                                },
                                percent: {
                                    fontSize: 10,
                                    color: '#fff',
                                },
                            },
                        },
                        // labelLine: {
                        //   length: 15,
                        //   length2: 0,
                        //   maxSurfaceAngle: 80,
                        // },
                        // labelLayout: function (params) {
                        //   const isLeft = params.labelRect.x < myChart.getWidth() / 2
                        //   const points = params.labelLinePoints
                        //   // Update the end point.
                        //   points[2][0] = isLeft
                        //     ? params.labelRect.x
                        //     : params.labelRect.x + params.labelRect.width
                        //   return {
                        //     labelLinePoints: points,
                        //   }
                        // },
                    },
                ],
            }

            option && myChart.setOption(option)
        },
        getTotal(arr) {
            let num = 0
            arr &&
                arr.forEach((item) => {
                    num += Number(item.value)
                })
            this.total = num
        },
        getRoadChart(data) {
            let chartDom = document.getElementById('roadChart')
            let myChart = echarts.init(chartDom)
            let arr3 = []
            let arr4 = []
            data.forEach((item) => {
                arr3.push(item.name)
                arr4.push({
                    value: item.number,
                    children: item.children,
                    name: item.name,
                })
            })
            this.getTotal(arr4.slice(0, 5))

            let option

            option = {
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'shadow',
                        crossStyle: {
                            color: '#999',
                        },
                    },
                    // 此处配置鼠标移动对应区域时的黑色弹框
                    trigger: 'axis',
                },
                toolbox: {
                    feature: {
                        show: true,
                        iconStyle: {
                            borderColor: '#fff',
                        },
                        myTool1: {
                            title: '还原',
                            icon: 'path://M512 981.333333c-209.866667 0-396.693333-126.026667-466.293333-314.08a35.52 35.52 0 0 1 23.626666-44.426666 38.613333 38.613333 0 0 1 48 20.693333c58.666667 158.933333 217.013333 265.493333 394.666667 265.6s336-106.666667 394.666667-266.133333a37.6 37.6 0 0 1 28.853333-23.626667 38.986667 38.986667 0 0 1 35.786667 11.946667 34.773333 34.773333 0 0 1 7.146666 35.36c-69.386667 188.373333-256.48 314.666667-466.453333 314.666666z m431.36-574.08a37.92 37.92 0 0 1-35.946667-24.266666C849.386667 222.56 690.613333 114.88 512 114.72S174.72 222.346667 116.746667 382.773333A38.72 38.72 0 0 1 69.333333 403.733333a35.786667 35.786667 0 0 1-24.106666-44.373333C113.333333 169.866667 301.013333 42.666667 512 42.666667s398.666667 127.306667 467.146667 316.96a34.56 34.56 0 0 1-4.906667 32.64 38.933333 38.933333 0 0 1-30.88 14.986666z',
                            tooltip: {
                                position: 'top',
                            },
                            iconStyle: {
                                borderColor: '#fff',
                            },
                            onclick: () => {
                                let option = myChart.getOption()
                                option.series[0].data = arr4
                                this.getTotal(arr4.slice(0, 5))
                                option.title = {
                                    text: `总数：${this.total}`,
                                    textStyle: {
                                        color: '#fff',
                                    },
                                }
                                option.yAxis = {
                                    type: 'category',
                                    data: arr3,
                                    axisPointer: {
                                        type: 'shadow',
                                    },
                                    axisLabel: {
                                        fontSize: 14,
                                        color: '#fff',
                                    },
                                    axisTick: {
                                        show: true,
                                        lineStyle: {
                                            color: '#fff',
                                        },
                                    },
                                    axisLine: {
                                        show: true,
                                        lineStyle: {
                                            color: '#fff',
                                        },
                                    },
                                }
                                myChart.setOption(option, true)
                            },
                        },
                    },
                },
                yAxis: {
                    type: 'category',
                    data: arr3,
                    axisPointer: {
                        type: 'shadow',
                    },
                    axisLabel: {
                        fontSize: 12,
                        color: '#fff',
                    },
                    axisTick: {
                        show: true,
                        lineStyle: {
                            color: '#fff',
                        },
                    },
                    axisLine: {
                        show: true,
                        lineStyle: {
                            color: '#fff',
                        },
                    },
                },
                title: {
                    text: `总数：${this.total}`,
                    textStyle: {
                        color: '#fff',
                    },
                },
                grid: {
                    top: 45,
                    left: 150,
                    right: 50,
                    bottom: 50,
                    width: 'auto',
                    height: 'auto',
                },
                xAxis: {
                    type: 'value',
                    splitLine: {show: false}, //去除网格线
                    axisLabel: {
                        // formatter: '{value}',
                        fontSize: 16,
                        color: '#fff',
                    },
                    axisTick: {
                        //y轴刻度线
                        show: true,
                        lineStyle: {
                            color: '#fff',
                        },
                    },
                    axisLine: {
                        //y轴
                        show: true,
                        lineStyle: {
                            color: '#fff',
                        },
                    },
                },
                series: [
                    {
                        type: 'bar',
                        tooltip: {
                            valueFormatter: function (value) {
                                return value + '个'
                            },
                        },
                        label: {
                            show: true,
                            position: 'right',
                            formatter: '{c} 个',
                            color: '#fff',
                        },
                        emphasis: {
                            itemStyle: {
                                shadowBlur: 10,
                                shadowColor: 'rgba(0,0,0,0.3)',
                            },
                            // focus : 'series'
                        },
                        itemStyle: {
                            normal: {
                                barBorderRadius: [0, 20, 20, 0],
                                color: new echarts.graphic.LinearGradient(0, 0, 1, 0, [
                                    {offset: 0, color: '#215579'},
                                    {offset: 0.5, color: '#2e91bd'},
                                    {offset: 1, color: '#37baeb'},
                                ]),
                            },
                        },
                        data: arr4,
                        barWidth: '25%',
                    },
                ],
            }

            option && myChart.setOption(option)
            myChart.on('click', 'series', (params) => {
                if (!params.data.children) {
                    return this.$router.push({
                        name: 'workOrderInfo',
                        params: {
                            value: params.data,
                            cstatusName: this.cstatus,
                        },
                    })
                } else {
                    this.cstatus = params.data.name
                }
                let nameArr = []
                let numberArr = []
                params.data.children &&
                    params.data.children.forEach((item) => {
                        nameArr.push(item.roadName)
                        numberArr.push({
                            value: item.number,
                            roadId: item.roadId,
                            name: item.roadName,
                        })
                    })
                let option = myChart.getOption()
                option.series[0].data = numberArr
                ;(option.title = {
                    text: `总数：${params.data.value}`,
                    textStyle: {
                        color: '#fff',
                    },
                }),
                    (option.yAxis = {
                        type: 'category',
                        data: nameArr,
                        axisPointer: {
                            type: 'shadow',
                        },
                        axisLabel: {
                            fontSize: 14,
                            color: '#fff',
                        },
                        axisTick: {
                            show: true,
                            lineStyle: {
                                color: '#fff',
                            },
                        },
                        axisLine: {
                            show: true,
                            lineStyle: {
                                color: '#fff',
                            },
                        },
                    })
                myChart.setOption(option, true) //设置为true时不会合并数据，而是重新刷新数据
            })
        },
        getStatusCharts(data) {
            let chartDom = document.getElementById('statusChart')
            let myChart = echarts.init(chartDom)
            let data_ = []

            data.forEach((item) => {
                data_.push({
                    value: item.number,
                    name: item.name,
                })
            })
            let option = {
                title: {
                    textStyle: {
                        color: '#fff',
                    },
                },
                legend: {
                    icon: 'circle',
                    orient: 'vertical',
                    right: 70,
                    top: 'center',
                    bottom: 20,
                    textStyle: {
                        color: '#ccc',
                    },
                },
                tooltip: {
                    trigger: 'item',
                    formatter: (a) => {
                        return `${a.marker} ${a.data.name} ${a.data.value}个 ${a.percent}%`
                    },
                },
                color: ['#68c1e5', '#578bf1', '#56d0a3', '#596d90', '#6a5cf1'],
                series: [
                    {
                        type: 'pie',
                        radius: ['40%', '55%'],
                        center: ['45%', '50%'],
                        data: data_,
                        width: '90%',
                        label: {
                            // alignTo: 'edge',
                            formatter: (a) => {
                                return `{percent|${a.percent}%}`
                            },
                            rich: {
                                percent: {
                                    fontSize: 15,
                                    color: '#fff',
                                },
                            },
                        },
                    },
                ],
            }

            option && myChart.setOption(option)
        },
    },
}
</script>

<style lang="scss" scoped>
* {
    margin: 0;
    padding: 0;
}
.content {
    // height: 100vh;
    display: flex;
    flex-direction: column;
}
/deep/ .el-form-item {
    margin-bottom: 0;
    padding: 10px;
}
.el-card_top {
    border-radius: 4px;
    border: 1px solid #113556;
    background-color: #103c5d !important;
    overflow: hidden;
    color: #303133;
    transition: 0.3s;
    box-shadow: 0 2px 12px #eee;
    margin-bottom: 10px;
}
.content-main {
    padding: 5px 10px;
    overflow: auto;
    flex: 1;
    .title {
        margin-top: 18px;
        margin-left: 20px;
        position: relative;
        h1 {
            font-size: 18px;
            font-weight: bold;
            margin: 0;
            &::after {
                position: absolute;
                content: '';
                display: block;
                width: 100%;
                height: 1px;
                bottom: -5px;
                background-color: #b4aaaa;
            }
            &::before {
                position: absolute;
                content: '';
                width: 15px;
                height: 15px;
                top: 5px;
                left: -20px;
                transform: rotate(45deg);
                background-color: #3ca4fd;
            }
        }
    }
    .main {
        display: flex;
        margin-top: 30px;
        .top {
            display: flex;
            position: relative;
            height: 35px;
            margin-left: 40px;
            align-items: flex-end;
            background-image: linear-gradient(to right, #336da2, #1c3c60);
            p {
                position: absolute;
                left: -18px;
                top: -1px;
                width: 30px;
                height: 30px;
                display: flex;
                justify-content: center;
                align-items: center;
                border: 1px solid #6184ac;
                background-color: #304e7b;
                transform: rotate(45deg);
                border-radius: 5px;
                i {
                    font-size: 25px;
                    color: #91f5f3;
                    transform: rotate(-45deg);
                }
            }
            h1 {
                margin-left: 25px;
                font-size: 16px;
                margin-bottom: 5px;
            }
        }
        .box {
            width: 100%;
            height: 280px;
            margin-top: 10px;
            border: 1px solid #1a86af;
            border-radius: 10px;
            overflow: auto;
            .box-item {
                padding: 0 25px;
                padding-top: 40px;
                display: flex;
                align-items: center;
                &:last-child {
                    padding-bottom: 40px;
                }
                .box-progress {
                    flex: 1;
                    margin: 0 20px;
                }
                span {
                    color: #b3f2d4;
                    font-size: 14px;
                }
            }
        }
        .item-left {
            flex: 1;
            margin-right: 10px;
        }
        .item-right {
            flex: 1.2;
        }
        .height_400 {
            height: 400px;
        }
    }
}
</style>
